
void export_collector();
void export_negotiator();
void export_schedd();
void export_credd();
void export_dc_tool();
void export_daemon_and_ad_types();
void export_daemon_location();
void export_config();
void export_secman();
void export_event_log();
void export_event_reader();
void export_log_reader();
void enable_classad_extensions();
void enable_deprecation_warnings();
void export_claim();
void export_startd();
void export_query_iterator();
void export_classad();
